import { SimpleGit, TaskOptions } from 'simple-git';
import Github from './Github';
import Gitlab from './gitlab';
import Gitee from './Gitee';
import { GitPlatformType, BranchType } from './interface';
declare class GitCore {
    projectName: string;
    version: string;
    sourceDir: string;
    git: SimpleGit;
    homePath: string;
    gitServer?: Github | Gitlab | Gitee;
    user?: unknown;
    orgs: unknown;
    owner?: string;
    loginName?: string;
    repo?: string;
    branch?: string;
    refreshRepo: boolean;
    refreshToken: boolean;
    refreshOwner: boolean;
    remote: string;
    token: string;
    gitType: GitPlatformType;
    constructor({ projectName, version, sourceDir, }: {
        projectName: string;
        version: string;
        sourceDir: string;
    }, { refreshRepo, refreshToken, refreshOwner }: {
        refreshRepo?: boolean | undefined;
        refreshToken?: boolean | undefined;
        refreshOwner?: boolean | undefined;
    });
    prepare(): Promise<void>;
    init(): Promise<void>;
    initAndAddRemote(): Promise<void>;
    initCommit(): Promise<void>;
    pullRemoteRepo(branchName: string, options?: TaskOptions): Promise<void>;
    pushRemoteRepo(branchName?: string): Promise<void>;
    commit(): Promise<void>;
    pullRemoteMainToBranch(): Promise<void>;
    checkoutBranch(branch: string | undefined): Promise<void>;
    checkStash(): Promise<void>;
    getCorrectVersion(): Promise<void>;
    getRemoteBranchList(type: BranchType): Promise<(string | undefined)[]>;
    checkRemoteMain(): Promise<boolean>;
    checkNotCommitted(): Promise<void>;
    checkConflicted(): Promise<void>;
    checkRepoAndCreate(): Promise<void>;
    checkGitServer(): Promise<void>;
    checkGitToken(): Promise<void>;
    getUserAndOrgs(): Promise<void>;
    checkGitOwner(): Promise<void>;
    checkHomePath(): Promise<void>;
    syncVersionToPackageJson(): void;
    getRemote(): true | undefined;
    checkGitIgnore(): void;
    createGitServer(gitType: GitPlatformType): Gitee | Gitlab | Github | undefined;
    createPath(file: string): string;
}
export default GitCore;
